==> hexo-theme-solitude-1.8.12.tgz: package/README_fr.md <==
[简体中文](README.md)丨[繁体中文](README_zh-Hant.md)丨[English](README_en-US.md)丨Français丨[日本語](README_ja.md)

<div align="center">

   <img src=".github/logo.svg" alt="Logo de la solitude" height="200">

   <h1>Thème Hexo Solitude</h1>

Un thème Hexo élégant qui prend en charge le chargement paresseux, les PWA, le latex et les systèmes de commentaires
multiples.

Le thème se compose de [@张洪Heo](https://github.com/zhheo) Autorisation complète de l’auteur, conception !

![npm package](https://img.shields.io/npm/v/hexo-theme-solitude?logo=npm)
![release](https://img.shields.io/github/package-json/v/valor-x/hexo-theme-solitude/master?color=%231ab1ad&label=release)
![license](https://img.shields.io/github/license/valor-x/hexo-theme-solitude?color=FF5531)
[![Stars](https://img.shields.io/github/stars/valor-x/hexo-theme-solitude)](https://github.com/valor-x/hexo-theme-solitude/stargazers)
[![NPM all downloads](https://img.shields.io/npm/dy/hexo-theme-solitude?color=white)](https://www.npmjs.com/package/hexo-theme-solitude)

![hexo version](https://img.shields.io/badge/hexo-7.0.0+-blue?logo=hexo&logoColor=white)
![node version](https://img.shields.io/badge/node-14.0.0-white?logo=node.js&logoColor=white)

![Latex](https://img.shields.io/badge/latex-20B2AA?logo=Latex)
![Ads](https://img.shields.io/badge/Google_Ads-black?logo=googleads)
![algolia](https://img.shields.io/badge/algolia-457AFF?logo=algolia)

![cdnjs](https://img.shields.io/badge/cdnjs-orange?logo=Cloudflare&logoColor=white)
![A11y](https://img.shields.io/badge/A11y-green?logo=%C3%8Ele-de-France%20Mobilit%C3%A9s&logoColor=white)
![mermaid](https://img.shields.io/badge/mermaid-ff3670?logo=mermaid&logoColor=white)
[![pwa](https://img.shields.io/badge/pwa-red?logo=pwa)](https://developer.mozilla.org/en-US/docs/Web/Progressive_web_apps)

[![twiter](https://img.shields.io/badge/Twitter-gray?logo=x)](https://twitter.com/efu_oo)
[![TG](https://img.shields.io/badge/Telegram-gray?logo=Telegram&logoColor=white)](https://t.me/solitudePro)
[![Discord](https://img.shields.io/discord/1218118131428495430?label=Discord&logo=Discord&labelColor=white&color=black)](https://discord.gg/Y8VEvVgW)

![JetBrains](https://img.shields.io/badge/jetbrains-support-black?logo=jetbrains)
![DuoLingo](https://img.shields.io/badge/duolingo-support-black?logo=duolingo&logoColor=white)

[![gitee](https://img.shields.io/badge/Gitee-red?logo=gitee)](https://gitee.com/nsjjd_w/hexo-theme-solitude)
[![gitlab](https://img.shields.io/badge/GitLab-blue?logo=gitlab)](https://gitlab.com/efu/hexo-theme-solitude)

[Aperçu](https://www.efu.me/) 丨  [documentation](https://solitude-docs.efu.me/)

</div>

![Screenshot](.github/screenshot.png)

## caractéristique

- Chargement paresseux de page (Pjax), chargement paresseux d’image (LazyLoad), application hors ligne (PWA)
- Commentaires (Twikoo, Waline, Valine, Artalk)
- Mode couleur
- Lightbox (zoom moyen, fancybox)
- Formules mathématiques (latex)
- Pages en vedette : Essais instantanés, Mon équipement, Outils en ligne, Galerie de musique, Étang à poissons Friend
  Chain, Page d’album photo, Page Douban
- Caractéristiques de l’article : résumé de l’IA, mise en évidence du code

## Todo

- [x] Examen d’Artalk
- [x] Double examen
- [x] album photo

> Si vous avez des questions, n’hésitez pas à les poser [issue](https://github.com/valor-x/hexo-theme-solitude/issues)

## appliquer

1. Utiliser le package NPM pour l’installation
      ```bash
      npm i hexo-theme-solitude
      ```
2. Appliquer un thème
      ```yaml
      theme: solitude
      ```

Go to [Docs](https://solitude-docs.efu.me) for more information.

## Sponsors

<p align="center">
  <a href="https://cdn.jsdelivr.net/gh/efuo/static/sponsors.svg">
    <img src='https://cdn.jsdelivr.net/gh/efuo/static/sponsors.svg'/>
  </a>
</p>

## copyright

[MIT](./LICENSE) License &copy; 2023-jusqu’ici [Efu](https://github.com/efuo)

==> hexo-theme-solitude-1.9.0.tgz: package/README_fr.md <==
[简体中文](README.md)丨[繁体中文](README_zh-Hant.md)丨[English](README_en-US.md)丨Français丨[日本語](README_ja.md)

<div align="center">

   <img src=".github/logo.svg" alt="Logo de la solitude" height="200">

   <h1>Thème Hexo Solitude</h1>

Un thème Hexo élégant qui prend en charge le chargement paresseux, les PWA, le latex et les systèmes de commentaires
multiples.

Le thème se compose de [@张洪Heo](https://github.com/zhheo) Autorisation complète de l’auteur, conception !

![npm package](https://img.shields.io/npm/v/hexo-theme-solitude?logo=npm)
![release](https://img.shields.io/github/package-json/v/valor-x/hexo-theme-solitude/master?color=%231ab1ad&label=release)
![license](https://img.shields.io/github/license/valor-x/hexo-theme-solitude?color=FF5531)
[![Stars](https://img.shields.io/github/stars/valor-x/hexo-theme-solitude)](https://github.com/valor-x/hexo-theme-solitude/stargazers)
[![NPM all downloads](https://img.shields.io/npm/dy/hexo-theme-solitude?color=white)](https://www.npmjs.com/package/hexo-theme-solitude)

![hexo version](https://img.shields.io/badge/hexo-7.0.0+-blue?logo=hexo&logoColor=white)
![node version](https://img.shields.io/badge/node-14.0.0-white?logo=node.js&logoColor=white)

![Latex](https://img.shields.io/badge/latex-20B2AA?logo=Latex)
![Ads](https://img.shields.io/badge/Google_Ads-black?logo=googleads)
![algolia](https://img.shields.io/badge/algolia-457AFF?logo=algolia)

![cdnjs](https://img.shields.io/badge/cdnjs-orange?logo=Cloudflare&logoColor=white)
![A11y](https://img.shields.io/badge/A11y-green?logo=%C3%8Ele-de-France%20Mobilit%C3%A9s&logoColor=white)
![mermaid](https://img.shields.io/badge/mermaid-ff3670?logo=mermaid&logoColor=white)
[![pwa](https://img.shields.io/badge/pwa-red?logo=pwa)](https://developer.mozilla.org/en-US/docs/Web/Progressive_web_apps)

[![twiter](https://img.shields.io/badge/Twitter-gray?logo=x)](https://twitter.com/efu_oo)
[![TG](https://img.shields.io/badge/Telegram-gray?logo=Telegram&logoColor=white)](https://t.me/solitudePro)
[![Discord](https://img.shields.io/discord/1218118131428495430?label=Discord&logo=Discord&labelColor=white&color=black)](https://discord.gg/Y8VEvVgW)

![JetBrains](https://img.shields.io/badge/jetbrains-support-black?logo=jetbrains)
![DuoLingo](https://img.shields.io/badge/duolingo-support-black?logo=duolingo&logoColor=white)

[![gitee](https://img.shields.io/badge/Gitee-red?logo=gitee)](https://gitee.com/nsjjd_w/hexo-theme-solitude)
[![gitlab](https://img.shields.io/badge/GitLab-blue?logo=gitlab)](https://gitlab.com/efu/hexo-theme-solitude)

[Aperçu](https://www.efu.me/) 丨  [documentation](https://docs.efu.me/)

</div>

![Screenshot](.github/screenshot.png)

## caractéristique

- Chargement paresseux de page (Pjax), chargement paresseux d’image (LazyLoad), application hors ligne (PWA)
- Commentaires (Twikoo, Waline, Valine, Artalk)
- Mode couleur
- Lightbox (zoom moyen, fancybox)
- Formules mathématiques (latex)
- Pages en vedette : Essais instantanés, Mon équipement, Outils en ligne, Galerie de musique, Étang à poissons Friend
  Chain, Page d’album photo, Page Douban
- Caractéristiques de l’article : résumé de l’IA, mise en évidence du code

## Todo

- [x] Examen d’Artalk
- [x] Double examen
- [x] album photo

> Si vous avez des questions, n’hésitez pas à les poser [issue](https://github.com/valor-x/hexo-theme-solitude/issues)

## appliquer

1. Utiliser le package NPM pour l’installation
      ```bash
      npm i hexo-theme-solitude
      ```
2. Appliquer un thème
      ```yaml
      theme: solitude
      ```

Go to [Docs](https://docs.efu.me) for more information.

## Sponsors

<p align="center">
  <a href="https://cdn.jsdelivr.net/gh/efuo/static/sponsors.svg">
    <img src='https://cdn.jsdelivr.net/gh/efuo/static/sponsors.svg'/>
  </a>
</p>

## copyright

[MIT](./LICENSE) License &copy; 2023-jusqu’ici [Efu](https://github.com/efuo)
